@@ -65,8 +65,21 @@ module Clamp
       end
 
       def define_appender_for(option)
-        define_method(option.append_method) do |value|
-          LogStash::SETTINGS.get_value(option.attribute_name) << value
+        if option.attribute_name == "SETTINGS_PASSTHROUGH"
+          define_method(option.append_method) do |kv_pair|
+            key, value = kv_pair.split(/[:=]/, 2)
+            signal_usage_error("failed to parse setting `#{kv_pair}`") unless key && value
+            signal_usage_error("failed to apply setting `#{kv_pair}`: unknown setting `#{key}`") unless LogStash::SETTINGS.registered?(key)
+            if value.empty?
+              LogStash::SETTINGS.get_setting(key).reset rescue signal_usage_error("failed to reset setting `#{kv_pair}`: #{$!.message}")
+            else
+              LogStash::SETTINGS.set_value(key, value) rescue signal_usage_error("failed to apply setting `#{kv_pair}`: #{$!.message}")
+            end
+          end
+        else
+          define_method(option.append_method) do |value|
+            LogStash::SETTINGS.get_value(option.attribute_name) << value
+          end
         end
       end
 
